package VMOMI::DpmBehavior;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
